#!/usr/bin/perl

use strict;
open(FIN,"todesfaelle20.txt");
my @lines = <FIN>;
close(FIN);
shift @lines; # title column
my $start = shift; # startweek
$start=1 if $start eq ""; # start at first week of year
my $end = shift; # endweek
if ($end<1 || $end>53) {
	if ($start>1) {
		$end = $start-1; # end at previous week of next year
	} else {
		$end=53; # end at last week of current year
	}
}
my $startjahr=2010;
my $endjahr=2020;
$endjahr=2021 if $start==1 && $end==16;
my $one53=0;
my %einwohner = (2010=>786,2011=>795,2012=>804,2013=>814,2014=>824,
	2015=>833,2016=>842,2017=>848,2018=>854,2019=>860,2020=>867,2021=>867);
my $maxwohner = $einwohner{$startjahr};
foreach my $jahr (keys %einwohner) {
	$maxwohner = $einwohner{$jahr} if $einwohner{$jahr}>$maxwohner;
}
my @faelle = (); # total cases of a period (year/week-year1/week-1)
my %cases = (); # hash for all mortage cases
my @kw53 = (); # 0=if current year has 52 weeks, 1 if year has 53 weeks

foreach my $line (@lines) {
	my ($jahr,$kw,$datum,$alter,$tfaelle,$rest) = split(/\,/,$line);
	chomp $tfaelle;
	if ($tfaelle>0) {
		$alter =~ s/\s//g;
		$alter =~ s/\t//g;
		my $old=0;
		$old=1 if $alter ne "0-64";
		$kw = "0$kw" if $kw<10;
		my $val = "$jahr$kw$old";
		$cases{$val}=int($tfaelle);
	}
}

sub getkey {
	my ($jahr,$kw,$old) = @_;
	$kw="0$kw" if $kw<10;
	return "$jahr$kw$old";
}

sub addfalls {
	my ($jahr,$kw,$old,$pcases,$pfaelle) = @_;
	my $key = getkey($jahr,$kw,$old);
	return $$pcases{$key};
}

for (my $jahr=$startjahr;$jahr<=$endjahr;$jahr++) {
	for (my $kw=$start;$kw<=$end;$kw++) {
		$faelle[$jahr]+=addfalls($jahr,$kw,0,\%cases);
		$faelle[$jahr]+=addfalls($jahr,$kw,1,\%cases);
	}
	if ($start>$end) {
		for (my $kw=$end;$kw<=53;$kw++) {
			$faelle[$jahr]+=addfalls($jahr,$kw,0,\%cases);
			$faelle[$jahr]+=addfalls($jahr,$kw,1,\%cases);
		}
		my $jahr0 = $jahr+1; # part for next year
		for (my $kw=1;$kw<$start;$kw++) {
			$faelle[$jahr]+=addfalls($jahr0,$kw,0,\%cases);
			$faelle[$jahr]+=addfalls($jahr0,$kw,1,\%cases);
		}

	}
	if ($start>$end || $end==53) {
		$kw53[$jahr]=1 if $cases{getkey($jahr,53,0)}>0;
		$one53=1 if $kw53[$jahr]==1;
	}
}

print "\nTodesfälle Schweiz Jahr/Kalenderwoche mit Vergleich Wohnbevölkerung\n\n";
for (my $jahr=$startjahr;$jahr<=$endjahr;$jahr++) {
 	my $all = $faelle[$jahr];
	my $all0 = $all; # correct for 52 weeks overall
	my $jahra = $jahr;
	my $kwa = $start;
	my $kwb = $end;
	$kwb=52 if $kw53[$jahr]==0 && $kwb==53;

	my $jahrb = $jahra;
	$jahrb++ if $start>1;
	my $stern = "";
	if ($kw53[$jahr]==1) {
		$stern = '*';
		$all0 = int($all0/(53/52.0));
	}
	my $faktor = $einwohner{$jahr}/$maxwohner;
	my $hoch = int($all0/$faktor);
	my $einw0 = $einwohner{$jahr}/100;
	my $einw = sprintf("%.2f",$einw0);
	my $maxw = sprintf("%.2f",$maxwohner/100);
	my $tausend = int($all0/$einwohner{$jahr});
	print "Todesfälle $jahra/$kwa-$jahrb/$kwb: $all0$stern ($einw Mio Einw.)".
	  " bzw. $tausend auf 100000 Einw.\n";
}

if ($one53==1) {
	print "\n* Datenbasis enthielt 53 Wochen, bereinigt auf 52 Wochen";
}
print "\nZahlenmaterial: Bundesamt für Statistik, wöchentliche Todesfälle\n";

